import sys
# the sys module must be reloaded otherwise setdefaultencoding is unknown
reload(sys)  # noqa: F821
sys.setdefaultencoding('utf8')
